Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(287)

Unified Diff: ash/common/system/networking_config_delegate.h

Issue 2698473007: Convert path usage in NetworkListViewBase subclasses to use guids. (Closed)
Patch Set: service_path to guid across all of ash Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/common/system/networking_config_delegate.h
diff --git a/ash/common/system/networking_config_delegate.h b/ash/common/system/networking_config_delegate.h
index e7c607dddd042aa9664a020164f476b97837492a..e701bf66052266c51142abcfee9d90a0b263b56a 100644
--- a/ash/common/system/networking_config_delegate.h
+++ b/ash/common/system/networking_config_delegate.h
@@ -15,7 +15,7 @@ namespace ash {
// This delegate allows the UI code in ash, e.g. |NetworkStateListDetailedView|,
// to access the |NetworkingConfigService| in order to determine whether the
// configuration of a network identified by its |service_path| is controlled by
// an extension.
// TODO(crbug.com/651157): Eliminate this delegate. Information about extension
// controlled networks should be provided by a mojo service that caches data at
@@ -34,9 +34,9 @@ class NetworkingConfigDelegate {
virtual ~NetworkingConfigDelegate() {}
// Returns information about the extension registered to control configuration
// of the network |service_path|. Returns null if no extension is registered.
virtual std::unique_ptr<const ExtensionInfo> LookUpExtensionForNetwork(
- const std::string& service_path) = 0;
+ const std::string& guid) = 0;
private:
DISALLOW_ASSIGN(NetworkingConfigDelegate);
@@ -15,7 +15,7 @@ namespace ash {
// This delegate allows the UI code in ash, e.g. |NetworkStateListDetailedView|,
// to access the |NetworkingConfigService| in order to determine whether the
-// configuration of a network identified by its |service_path| is controlled by
+// configuration of a network identified by its |guid| is controlled by
// an extension.
// TODO(crbug.com/651157): Eliminate this delegate. Information about extension
@@ -34,9 +34,9 @@ class NetworkingConfigDelegate {
virtual ~NetworkingConfigDelegate() {}
// Returns information about the extension registered to control configuration
- // of the network |service_path|. Returns null if no extension is registered.
+ // of the network |guid|. Returns null if no extension is registered.
virtual std::unique_ptr<const ExtensionInfo> LookUpExtensionForNetwork(

Powered by Google App Engine
This is Rietveld 408576698